MatchMakerMonitoring.on_close() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerMonitoring.on_close()

MatchMakerMonitoring.on_close()

  Executed once, when the page is closed, before data saving.

  This is your go-to-hook, if you want to have the page execute this code only once, when submitting the data from a page. After a page is closed, there can be no more changes to subject input. This is the most important difference of `on_close()` from `on_first_hide()` and :meth`on_each_hide`.

  See also

  See “How to use hooks” for a how to on using hooks and an overview of available hooks.